# Simulation of Systems of Particles with High Efficiency

Please visit the [website](https://sisyphe.readthedocs.io/en/latest/) for a full documentation.

# Author

- [Antoine Diez](https://antoinediez.gitlab.io)